# Strats

[![Test](https://github.com/kazukiyoshida/strats/actions/workflows/test.yaml/badge.svg)](https://github.com/kazukiyoshida/strats/actions/workflows/test.yaml)

Strats is a modern, lightweight trading system framework with Python.
